#!/bin/bash
server_url=$1
deploy_key=$2
listen_ip=${3:-0.0.0.0}
listen_port=${4:-80}

if [ $# -lt 2 ]
    then
        echo "Wrong number of arguments supplied."
        echo "Usage: $0 <server_url> <deploy_key> <listen_ip> <listen_port>."
        echo "listen_ip and listen_port are optional."
        echo "listen_ip default value is 0.0.0.0"
        echo "listen_port default value is 80"
        exit 1
fi

register(){
server_url=$1
deploy_key=$2
honeypot=$3
hostname=$(hostname)

curl -s -X POST -H "Content-Type: application/json" -d "{
        \"name\": \"${hostname}-${honeypot}\", 
        \"hostname\": \"$hostname\", 
        \"deploy_key\": \"$deploy_key\",
        \"honeypot\": \"$honeypot\"
}" $server_url/api/sensor/ > /tmp/deploy.json

uuid=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["uuid"]')

if [ -z "$uuid" ]
    then
        echo "Could not create sensor using name \"$hostname\"."
        exit 1
fi

set -e

echo "Created sensor: " $uuid

######################################################
# hpfeeds info
export HPF_HOST=$(echo $server_url | sed 's#^http://##; s#^https://##; s#/.*$##; s/:.*$//')
export HPF_PORT="10000"
export HPF_IDENT=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["identifier"]')
export HPF_SECRET=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["secret"]')
######################################################
}

register $server_url $deploy_key "wordpot"

conf=/usr/share/wordpot/wordpot.conf

sed -i "/^HOST/ s/HOST.*/HOST = '$listen_ip'/" $conf
sed -i "/^PORT/ s/PORT.*/PORT = '$listen_port'/" $conf

#HPFEEDS
sed -i "/^HPFEEDS_ENABLED/ s/HPFEEDS_ENABLED.*/HPFEEDS_ENABLED = True/" $conf
sed -i "/^HPFEEDS_HOST/ s/HPFEEDS_HOST.*/HPFEEDS_HOST = '$HPF_HOST'/" $conf
sed -i "/^HPFEEDS_PORT/ s/HPFEEDS_PORT.*/HPFEEDS_PORT = $HPF_PORT/" $conf
sed -i "/^HPFEEDS_IDENT/ s/HPFEEDS_IDENT.*/HPFEEDS_IDENT = '$HPF_IDENT'/" $conf
sed -i "/^HPFEEDS_SECRET/ s/HPFEEDS_SECRET.*/HPFEEDS_SECRET = '$HPF_SECRET'/" $conf

systemctl restart wordpot

